# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ContainerRegistryOIDCArgs', 'ContainerRegistryOIDC']

@pulumi.input_type
class ContainerRegistryOIDCArgs:
    def __init__(__self__, *,
                 oidc_client_id: pulumi.Input[builtins.str],
                 oidc_client_secret: pulumi.Input[builtins.str],
                 oidc_endpoint: pulumi.Input[builtins.str],
                 oidc_name: pulumi.Input[builtins.str],
                 oidc_scope: pulumi.Input[builtins.str],
                 registry_id: pulumi.Input[builtins.str],
                 service_name: pulumi.Input[builtins.str],
                 delete_users: Optional[pulumi.Input[builtins.bool]] = None,
                 oidc_admin_group: Optional[pulumi.Input[builtins.str]] = None,
                 oidc_auto_onboard: Optional[pulumi.Input[builtins.bool]] = None,
                 oidc_groups_claim: Optional[pulumi.Input[builtins.str]] = None,
                 oidc_user_claim: Optional[pulumi.Input[builtins.str]] = None,
                 oidc_verify_cert: Optional[pulumi.Input[builtins.bool]] = None):
        """
        The set of arguments for constructing a ContainerRegistryOIDC resource.
        :param pulumi.Input[builtins.str] oidc_client_id: The client ID with which Harbor is registered as client application with the OIDC provider.
        :param pulumi.Input[builtins.str] oidc_client_secret: The secret for the Harbor client application.
        :param pulumi.Input[builtins.str] oidc_endpoint: The URL of an OIDC-compliant server.
        :param pulumi.Input[builtins.str] oidc_name: The name of the OIDC provider.
        :param pulumi.Input[builtins.str] oidc_scope: The scope sent to OIDC server during authentication. It's a comma-separated string that must contain 'openid' and usually also contains 'profile' and 'email'. To obtain refresh tokens it should also contain 'offline_access'.
        :param pulumi.Input[builtins.str] registry_id: The ID of the Managed Private Registry. **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] service_name: The ID of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used. **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.bool] delete_users: Delete existing users from Harbor. OIDC can't be enabled if there is at least one user already created. This parameter is only used at OIDC configuration creation. **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] oidc_admin_group: Specify an OIDC admin group name. All OIDC users in this group will have harbor admin privilege. Keep it blank if you do not want to.
        :param pulumi.Input[builtins.bool] oidc_auto_onboard: Skip the onboarding screen, so user cannot change its username. Username is provided from ID Token.
        :param pulumi.Input[builtins.str] oidc_groups_claim: The name of Claim in the ID token whose value is the list of group names.
        :param pulumi.Input[builtins.str] oidc_user_claim: The name of the claim in the ID Token where the username is retrieved from. If not specified, it will default to 'name' (only useful when automatic Onboarding is enabled).
        :param pulumi.Input[builtins.bool] oidc_verify_cert: Set it to `false` if your OIDC server is hosted via self-signed certificate.
        """
        pulumi.set(__self__, "oidc_client_id", oidc_client_id)
        pulumi.set(__self__, "oidc_client_secret", oidc_client_secret)
        pulumi.set(__self__, "oidc_endpoint", oidc_endpoint)
        pulumi.set(__self__, "oidc_name", oidc_name)
        pulumi.set(__self__, "oidc_scope", oidc_scope)
        pulumi.set(__self__, "registry_id", registry_id)
        pulumi.set(__self__, "service_name", service_name)
        if delete_users is not None:
            pulumi.set(__self__, "delete_users", delete_users)
        if oidc_admin_group is not None:
            pulumi.set(__self__, "oidc_admin_group", oidc_admin_group)
        if oidc_auto_onboard is not None:
            pulumi.set(__self__, "oidc_auto_onboard", oidc_auto_onboard)
        if oidc_groups_claim is not None:
            pulumi.set(__self__, "oidc_groups_claim", oidc_groups_claim)
        if oidc_user_claim is not None:
            pulumi.set(__self__, "oidc_user_claim", oidc_user_claim)
        if oidc_verify_cert is not None:
            pulumi.set(__self__, "oidc_verify_cert", oidc_verify_cert)

    @property
    @pulumi.getter(name="oidcClientId")
    def oidc_client_id(self) -> pulumi.Input[builtins.str]:
        """
        The client ID with which Harbor is registered as client application with the OIDC provider.
        """
        return pulumi.get(self, "oidc_client_id")

    @oidc_client_id.setter
    def oidc_client_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "oidc_client_id", value)

    @property
    @pulumi.getter(name="oidcClientSecret")
    def oidc_client_secret(self) -> pulumi.Input[builtins.str]:
        """
        The secret for the Harbor client application.
        """
        return pulumi.get(self, "oidc_client_secret")

    @oidc_client_secret.setter
    def oidc_client_secret(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "oidc_client_secret", value)

    @property
    @pulumi.getter(name="oidcEndpoint")
    def oidc_endpoint(self) -> pulumi.Input[builtins.str]:
        """
        The URL of an OIDC-compliant server.
        """
        return pulumi.get(self, "oidc_endpoint")

    @oidc_endpoint.setter
    def oidc_endpoint(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "oidc_endpoint", value)

    @property
    @pulumi.getter(name="oidcName")
    def oidc_name(self) -> pulumi.Input[builtins.str]:
        """
        The name of the OIDC provider.
        """
        return pulumi.get(self, "oidc_name")

    @oidc_name.setter
    def oidc_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "oidc_name", value)

    @property
    @pulumi.getter(name="oidcScope")
    def oidc_scope(self) -> pulumi.Input[builtins.str]:
        """
        The scope sent to OIDC server during authentication. It's a comma-separated string that must contain 'openid' and usually also contains 'profile' and 'email'. To obtain refresh tokens it should also contain 'offline_access'.
        """
        return pulumi.get(self, "oidc_scope")

    @oidc_scope.setter
    def oidc_scope(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "oidc_scope", value)

    @property
    @pulumi.getter(name="registryId")
    def registry_id(self) -> pulumi.Input[builtins.str]:
        """
        The ID of the Managed Private Registry. **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "registry_id")

    @registry_id.setter
    def registry_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "registry_id", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[builtins.str]:
        """
        The ID of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used. **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter(name="deleteUsers")
    def delete_users(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Delete existing users from Harbor. OIDC can't be enabled if there is at least one user already created. This parameter is only used at OIDC configuration creation. **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "delete_users")

    @delete_users.setter
    def delete_users(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "delete_users", value)

    @property
    @pulumi.getter(name="oidcAdminGroup")
    def oidc_admin_group(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Specify an OIDC admin group name. All OIDC users in this group will have harbor admin privilege. Keep it blank if you do not want to.
        """
        return pulumi.get(self, "oidc_admin_group")

    @oidc_admin_group.setter
    def oidc_admin_group(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "oidc_admin_group", value)

    @property
    @pulumi.getter(name="oidcAutoOnboard")
    def oidc_auto_onboard(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Skip the onboarding screen, so user cannot change its username. Username is provided from ID Token.
        """
        return pulumi.get(self, "oidc_auto_onboard")

    @oidc_auto_onboard.setter
    def oidc_auto_onboard(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "oidc_auto_onboard", value)

    @property
    @pulumi.getter(name="oidcGroupsClaim")
    def oidc_groups_claim(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of Claim in the ID token whose value is the list of group names.
        """
        return pulumi.get(self, "oidc_groups_claim")

    @oidc_groups_claim.setter
    def oidc_groups_claim(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "oidc_groups_claim", value)

    @property
    @pulumi.getter(name="oidcUserClaim")
    def oidc_user_claim(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the claim in the ID Token where the username is retrieved from. If not specified, it will default to 'name' (only useful when automatic Onboarding is enabled).
        """
        return pulumi.get(self, "oidc_user_claim")

    @oidc_user_claim.setter
    def oidc_user_claim(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "oidc_user_claim", value)

    @property
    @pulumi.getter(name="oidcVerifyCert")
    def oidc_verify_cert(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Set it to `false` if your OIDC server is hosted via self-signed certificate.
        """
        return pulumi.get(self, "oidc_verify_cert")

    @oidc_verify_cert.setter
    def oidc_verify_cert(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "oidc_verify_cert", value)


@pulumi.input_type
class _ContainerRegistryOIDCState:
    def __init__(__self__, *,
                 delete_users: Optional[pulumi.Input[builtins.bool]] = None,
                 oidc_admin_group: Optional[pulumi.Input[builtins.str]] = None,
                 oidc_auto_onboard: Optional[pulumi.Input[builtins.bool]] = None,
                 oidc_client_id: Optional[pulumi.Input[builtins.str]] = None,
                 oidc_client_secret: Optional[pulumi.Input[builtins.str]] = None,
                 oidc_endpoint: Optional[pulumi.Input[builtins.str]] = None,
                 oidc_groups_claim: Optional[pulumi.Input[builtins.str]] = None,
                 oidc_name: Optional[pulumi.Input[builtins.str]] = None,
                 oidc_scope: Optional[pulumi.Input[builtins.str]] = None,
                 oidc_user_claim: Optional[pulumi.Input[builtins.str]] = None,
                 oidc_verify_cert: Optional[pulumi.Input[builtins.bool]] = None,
                 registry_id: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering ContainerRegistryOIDC resources.
        :param pulumi.Input[builtins.bool] delete_users: Delete existing users from Harbor. OIDC can't be enabled if there is at least one user already created. This parameter is only used at OIDC configuration creation. **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] oidc_admin_group: Specify an OIDC admin group name. All OIDC users in this group will have harbor admin privilege. Keep it blank if you do not want to.
        :param pulumi.Input[builtins.bool] oidc_auto_onboard: Skip the onboarding screen, so user cannot change its username. Username is provided from ID Token.
        :param pulumi.Input[builtins.str] oidc_client_id: The client ID with which Harbor is registered as client application with the OIDC provider.
        :param pulumi.Input[builtins.str] oidc_client_secret: The secret for the Harbor client application.
        :param pulumi.Input[builtins.str] oidc_endpoint: The URL of an OIDC-compliant server.
        :param pulumi.Input[builtins.str] oidc_groups_claim: The name of Claim in the ID token whose value is the list of group names.
        :param pulumi.Input[builtins.str] oidc_name: The name of the OIDC provider.
        :param pulumi.Input[builtins.str] oidc_scope: The scope sent to OIDC server during authentication. It's a comma-separated string that must contain 'openid' and usually also contains 'profile' and 'email'. To obtain refresh tokens it should also contain 'offline_access'.
        :param pulumi.Input[builtins.str] oidc_user_claim: The name of the claim in the ID Token where the username is retrieved from. If not specified, it will default to 'name' (only useful when automatic Onboarding is enabled).
        :param pulumi.Input[builtins.bool] oidc_verify_cert: Set it to `false` if your OIDC server is hosted via self-signed certificate.
        :param pulumi.Input[builtins.str] registry_id: The ID of the Managed Private Registry. **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] service_name: The ID of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used. **Changing this value recreates the resource.**
        """
        if delete_users is not None:
            pulumi.set(__self__, "delete_users", delete_users)
        if oidc_admin_group is not None:
            pulumi.set(__self__, "oidc_admin_group", oidc_admin_group)
        if oidc_auto_onboard is not None:
            pulumi.set(__self__, "oidc_auto_onboard", oidc_auto_onboard)
        if oidc_client_id is not None:
            pulumi.set(__self__, "oidc_client_id", oidc_client_id)
        if oidc_client_secret is not None:
            pulumi.set(__self__, "oidc_client_secret", oidc_client_secret)
        if oidc_endpoint is not None:
            pulumi.set(__self__, "oidc_endpoint", oidc_endpoint)
        if oidc_groups_claim is not None:
            pulumi.set(__self__, "oidc_groups_claim", oidc_groups_claim)
        if oidc_name is not None:
            pulumi.set(__self__, "oidc_name", oidc_name)
        if oidc_scope is not None:
            pulumi.set(__self__, "oidc_scope", oidc_scope)
        if oidc_user_claim is not None:
            pulumi.set(__self__, "oidc_user_claim", oidc_user_claim)
        if oidc_verify_cert is not None:
            pulumi.set(__self__, "oidc_verify_cert", oidc_verify_cert)
        if registry_id is not None:
            pulumi.set(__self__, "registry_id", registry_id)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)

    @property
    @pulumi.getter(name="deleteUsers")
    def delete_users(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Delete existing users from Harbor. OIDC can't be enabled if there is at least one user already created. This parameter is only used at OIDC configuration creation. **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "delete_users")

    @delete_users.setter
    def delete_users(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "delete_users", value)

    @property
    @pulumi.getter(name="oidcAdminGroup")
    def oidc_admin_group(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Specify an OIDC admin group name. All OIDC users in this group will have harbor admin privilege. Keep it blank if you do not want to.
        """
        return pulumi.get(self, "oidc_admin_group")

    @oidc_admin_group.setter
    def oidc_admin_group(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "oidc_admin_group", value)

    @property
    @pulumi.getter(name="oidcAutoOnboard")
    def oidc_auto_onboard(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Skip the onboarding screen, so user cannot change its username. Username is provided from ID Token.
        """
        return pulumi.get(self, "oidc_auto_onboard")

    @oidc_auto_onboard.setter
    def oidc_auto_onboard(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "oidc_auto_onboard", value)

    @property
    @pulumi.getter(name="oidcClientId")
    def oidc_client_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The client ID with which Harbor is registered as client application with the OIDC provider.
        """
        return pulumi.get(self, "oidc_client_id")

    @oidc_client_id.setter
    def oidc_client_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "oidc_client_id", value)

    @property
    @pulumi.getter(name="oidcClientSecret")
    def oidc_client_secret(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The secret for the Harbor client application.
        """
        return pulumi.get(self, "oidc_client_secret")

    @oidc_client_secret.setter
    def oidc_client_secret(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "oidc_client_secret", value)

    @property
    @pulumi.getter(name="oidcEndpoint")
    def oidc_endpoint(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The URL of an OIDC-compliant server.
        """
        return pulumi.get(self, "oidc_endpoint")

    @oidc_endpoint.setter
    def oidc_endpoint(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "oidc_endpoint", value)

    @property
    @pulumi.getter(name="oidcGroupsClaim")
    def oidc_groups_claim(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of Claim in the ID token whose value is the list of group names.
        """
        return pulumi.get(self, "oidc_groups_claim")

    @oidc_groups_claim.setter
    def oidc_groups_claim(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "oidc_groups_claim", value)

    @property
    @pulumi.getter(name="oidcName")
    def oidc_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the OIDC provider.
        """
        return pulumi.get(self, "oidc_name")

    @oidc_name.setter
    def oidc_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "oidc_name", value)

    @property
    @pulumi.getter(name="oidcScope")
    def oidc_scope(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The scope sent to OIDC server during authentication. It's a comma-separated string that must contain 'openid' and usually also contains 'profile' and 'email'. To obtain refresh tokens it should also contain 'offline_access'.
        """
        return pulumi.get(self, "oidc_scope")

    @oidc_scope.setter
    def oidc_scope(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "oidc_scope", value)

    @property
    @pulumi.getter(name="oidcUserClaim")
    def oidc_user_claim(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the claim in the ID Token where the username is retrieved from. If not specified, it will default to 'name' (only useful when automatic Onboarding is enabled).
        """
        return pulumi.get(self, "oidc_user_claim")

    @oidc_user_claim.setter
    def oidc_user_claim(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "oidc_user_claim", value)

    @property
    @pulumi.getter(name="oidcVerifyCert")
    def oidc_verify_cert(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Set it to `false` if your OIDC server is hosted via self-signed certificate.
        """
        return pulumi.get(self, "oidc_verify_cert")

    @oidc_verify_cert.setter
    def oidc_verify_cert(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "oidc_verify_cert", value)

    @property
    @pulumi.getter(name="registryId")
    def registry_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the Managed Private Registry. **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "registry_id")

    @registry_id.setter
    def registry_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "registry_id", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used. **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)


class ContainerRegistryOIDC(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 delete_users: Optional[pulumi.Input[builtins.bool]] = None,
                 oidc_admin_group: Optional[pulumi.Input[builtins.str]] = None,
                 oidc_auto_onboard: Optional[pulumi.Input[builtins.bool]] = None,
                 oidc_client_id: Optional[pulumi.Input[builtins.str]] = None,
                 oidc_client_secret: Optional[pulumi.Input[builtins.str]] = None,
                 oidc_endpoint: Optional[pulumi.Input[builtins.str]] = None,
                 oidc_groups_claim: Optional[pulumi.Input[builtins.str]] = None,
                 oidc_name: Optional[pulumi.Input[builtins.str]] = None,
                 oidc_scope: Optional[pulumi.Input[builtins.str]] = None,
                 oidc_user_claim: Optional[pulumi.Input[builtins.str]] = None,
                 oidc_verify_cert: Optional[pulumi.Input[builtins.bool]] = None,
                 registry_id: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Creates an OIDC configuration in an OVHcloud Managed Private Registry.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        my_oidc = ovh.cloud_project.ContainerRegistryOIDC("my_oidc",
            service_name="XXXXXX",
            registry_id="xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxx",
            oidc_name="my-oidc-provider",
            oidc_endpoint="https://xxxx.yyy.com",
            oidc_client_id="xxx",
            oidc_client_secret="xxx",
            oidc_scope="openid,profile,email,offline_access",
            oidc_groups_claim="groups",
            oidc_admin_group="harbor-admin",
            oidc_verify_cert=True,
            oidc_auto_onboard=True,
            oidc_user_claim="preferred_username",
            delete_users=False)
        pulumi.export("oidcClientSecret", my_oidc.oidc_client_secret)
        ```

        ## Import

        OVHcloud Managed Private Registry OIDC can be imported using the tenant `service_name` and registry id `registry_id` separated by "/" E.g.,

        bash

        ```sh
        $ pulumi import ovh:CloudProject/containerRegistryOIDC:ContainerRegistryOIDC my-oidc service_name/registry_id
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] delete_users: Delete existing users from Harbor. OIDC can't be enabled if there is at least one user already created. This parameter is only used at OIDC configuration creation. **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] oidc_admin_group: Specify an OIDC admin group name. All OIDC users in this group will have harbor admin privilege. Keep it blank if you do not want to.
        :param pulumi.Input[builtins.bool] oidc_auto_onboard: Skip the onboarding screen, so user cannot change its username. Username is provided from ID Token.
        :param pulumi.Input[builtins.str] oidc_client_id: The client ID with which Harbor is registered as client application with the OIDC provider.
        :param pulumi.Input[builtins.str] oidc_client_secret: The secret for the Harbor client application.
        :param pulumi.Input[builtins.str] oidc_endpoint: The URL of an OIDC-compliant server.
        :param pulumi.Input[builtins.str] oidc_groups_claim: The name of Claim in the ID token whose value is the list of group names.
        :param pulumi.Input[builtins.str] oidc_name: The name of the OIDC provider.
        :param pulumi.Input[builtins.str] oidc_scope: The scope sent to OIDC server during authentication. It's a comma-separated string that must contain 'openid' and usually also contains 'profile' and 'email'. To obtain refresh tokens it should also contain 'offline_access'.
        :param pulumi.Input[builtins.str] oidc_user_claim: The name of the claim in the ID Token where the username is retrieved from. If not specified, it will default to 'name' (only useful when automatic Onboarding is enabled).
        :param pulumi.Input[builtins.bool] oidc_verify_cert: Set it to `false` if your OIDC server is hosted via self-signed certificate.
        :param pulumi.Input[builtins.str] registry_id: The ID of the Managed Private Registry. **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] service_name: The ID of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used. **Changing this value recreates the resource.**
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ContainerRegistryOIDCArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates an OIDC configuration in an OVHcloud Managed Private Registry.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        my_oidc = ovh.cloud_project.ContainerRegistryOIDC("my_oidc",
            service_name="XXXXXX",
            registry_id="xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxx",
            oidc_name="my-oidc-provider",
            oidc_endpoint="https://xxxx.yyy.com",
            oidc_client_id="xxx",
            oidc_client_secret="xxx",
            oidc_scope="openid,profile,email,offline_access",
            oidc_groups_claim="groups",
            oidc_admin_group="harbor-admin",
            oidc_verify_cert=True,
            oidc_auto_onboard=True,
            oidc_user_claim="preferred_username",
            delete_users=False)
        pulumi.export("oidcClientSecret", my_oidc.oidc_client_secret)
        ```

        ## Import

        OVHcloud Managed Private Registry OIDC can be imported using the tenant `service_name` and registry id `registry_id` separated by "/" E.g.,

        bash

        ```sh
        $ pulumi import ovh:CloudProject/containerRegistryOIDC:ContainerRegistryOIDC my-oidc service_name/registry_id
        ```

        :param str resource_name: The name of the resource.
        :param ContainerRegistryOIDCArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ContainerRegistryOIDCArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 delete_users: Optional[pulumi.Input[builtins.bool]] = None,
                 oidc_admin_group: Optional[pulumi.Input[builtins.str]] = None,
                 oidc_auto_onboard: Optional[pulumi.Input[builtins.bool]] = None,
                 oidc_client_id: Optional[pulumi.Input[builtins.str]] = None,
                 oidc_client_secret: Optional[pulumi.Input[builtins.str]] = None,
                 oidc_endpoint: Optional[pulumi.Input[builtins.str]] = None,
                 oidc_groups_claim: Optional[pulumi.Input[builtins.str]] = None,
                 oidc_name: Optional[pulumi.Input[builtins.str]] = None,
                 oidc_scope: Optional[pulumi.Input[builtins.str]] = None,
                 oidc_user_claim: Optional[pulumi.Input[builtins.str]] = None,
                 oidc_verify_cert: Optional[pulumi.Input[builtins.bool]] = None,
                 registry_id: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ContainerRegistryOIDCArgs.__new__(ContainerRegistryOIDCArgs)

            __props__.__dict__["delete_users"] = delete_users
            __props__.__dict__["oidc_admin_group"] = oidc_admin_group
            __props__.__dict__["oidc_auto_onboard"] = oidc_auto_onboard
            if oidc_client_id is None and not opts.urn:
                raise TypeError("Missing required property 'oidc_client_id'")
            __props__.__dict__["oidc_client_id"] = oidc_client_id
            if oidc_client_secret is None and not opts.urn:
                raise TypeError("Missing required property 'oidc_client_secret'")
            __props__.__dict__["oidc_client_secret"] = None if oidc_client_secret is None else pulumi.Output.secret(oidc_client_secret)
            if oidc_endpoint is None and not opts.urn:
                raise TypeError("Missing required property 'oidc_endpoint'")
            __props__.__dict__["oidc_endpoint"] = oidc_endpoint
            __props__.__dict__["oidc_groups_claim"] = oidc_groups_claim
            if oidc_name is None and not opts.urn:
                raise TypeError("Missing required property 'oidc_name'")
            __props__.__dict__["oidc_name"] = oidc_name
            if oidc_scope is None and not opts.urn:
                raise TypeError("Missing required property 'oidc_scope'")
            __props__.__dict__["oidc_scope"] = oidc_scope
            __props__.__dict__["oidc_user_claim"] = oidc_user_claim
            __props__.__dict__["oidc_verify_cert"] = oidc_verify_cert
            if registry_id is None and not opts.urn:
                raise TypeError("Missing required property 'registry_id'")
            __props__.__dict__["registry_id"] = registry_id
            if service_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_name'")
            __props__.__dict__["service_name"] = service_name
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["oidcClientSecret"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(ContainerRegistryOIDC, __self__).__init__(
            'ovh:CloudProject/containerRegistryOIDC:ContainerRegistryOIDC',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            delete_users: Optional[pulumi.Input[builtins.bool]] = None,
            oidc_admin_group: Optional[pulumi.Input[builtins.str]] = None,
            oidc_auto_onboard: Optional[pulumi.Input[builtins.bool]] = None,
            oidc_client_id: Optional[pulumi.Input[builtins.str]] = None,
            oidc_client_secret: Optional[pulumi.Input[builtins.str]] = None,
            oidc_endpoint: Optional[pulumi.Input[builtins.str]] = None,
            oidc_groups_claim: Optional[pulumi.Input[builtins.str]] = None,
            oidc_name: Optional[pulumi.Input[builtins.str]] = None,
            oidc_scope: Optional[pulumi.Input[builtins.str]] = None,
            oidc_user_claim: Optional[pulumi.Input[builtins.str]] = None,
            oidc_verify_cert: Optional[pulumi.Input[builtins.bool]] = None,
            registry_id: Optional[pulumi.Input[builtins.str]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None) -> 'ContainerRegistryOIDC':
        """
        Get an existing ContainerRegistryOIDC resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] delete_users: Delete existing users from Harbor. OIDC can't be enabled if there is at least one user already created. This parameter is only used at OIDC configuration creation. **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] oidc_admin_group: Specify an OIDC admin group name. All OIDC users in this group will have harbor admin privilege. Keep it blank if you do not want to.
        :param pulumi.Input[builtins.bool] oidc_auto_onboard: Skip the onboarding screen, so user cannot change its username. Username is provided from ID Token.
        :param pulumi.Input[builtins.str] oidc_client_id: The client ID with which Harbor is registered as client application with the OIDC provider.
        :param pulumi.Input[builtins.str] oidc_client_secret: The secret for the Harbor client application.
        :param pulumi.Input[builtins.str] oidc_endpoint: The URL of an OIDC-compliant server.
        :param pulumi.Input[builtins.str] oidc_groups_claim: The name of Claim in the ID token whose value is the list of group names.
        :param pulumi.Input[builtins.str] oidc_name: The name of the OIDC provider.
        :param pulumi.Input[builtins.str] oidc_scope: The scope sent to OIDC server during authentication. It's a comma-separated string that must contain 'openid' and usually also contains 'profile' and 'email'. To obtain refresh tokens it should also contain 'offline_access'.
        :param pulumi.Input[builtins.str] oidc_user_claim: The name of the claim in the ID Token where the username is retrieved from. If not specified, it will default to 'name' (only useful when automatic Onboarding is enabled).
        :param pulumi.Input[builtins.bool] oidc_verify_cert: Set it to `false` if your OIDC server is hosted via self-signed certificate.
        :param pulumi.Input[builtins.str] registry_id: The ID of the Managed Private Registry. **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] service_name: The ID of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used. **Changing this value recreates the resource.**
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ContainerRegistryOIDCState.__new__(_ContainerRegistryOIDCState)

        __props__.__dict__["delete_users"] = delete_users
        __props__.__dict__["oidc_admin_group"] = oidc_admin_group
        __props__.__dict__["oidc_auto_onboard"] = oidc_auto_onboard
        __props__.__dict__["oidc_client_id"] = oidc_client_id
        __props__.__dict__["oidc_client_secret"] = oidc_client_secret
        __props__.__dict__["oidc_endpoint"] = oidc_endpoint
        __props__.__dict__["oidc_groups_claim"] = oidc_groups_claim
        __props__.__dict__["oidc_name"] = oidc_name
        __props__.__dict__["oidc_scope"] = oidc_scope
        __props__.__dict__["oidc_user_claim"] = oidc_user_claim
        __props__.__dict__["oidc_verify_cert"] = oidc_verify_cert
        __props__.__dict__["registry_id"] = registry_id
        __props__.__dict__["service_name"] = service_name
        return ContainerRegistryOIDC(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="deleteUsers")
    def delete_users(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Delete existing users from Harbor. OIDC can't be enabled if there is at least one user already created. This parameter is only used at OIDC configuration creation. **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "delete_users")

    @property
    @pulumi.getter(name="oidcAdminGroup")
    def oidc_admin_group(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Specify an OIDC admin group name. All OIDC users in this group will have harbor admin privilege. Keep it blank if you do not want to.
        """
        return pulumi.get(self, "oidc_admin_group")

    @property
    @pulumi.getter(name="oidcAutoOnboard")
    def oidc_auto_onboard(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Skip the onboarding screen, so user cannot change its username. Username is provided from ID Token.
        """
        return pulumi.get(self, "oidc_auto_onboard")

    @property
    @pulumi.getter(name="oidcClientId")
    def oidc_client_id(self) -> pulumi.Output[builtins.str]:
        """
        The client ID with which Harbor is registered as client application with the OIDC provider.
        """
        return pulumi.get(self, "oidc_client_id")

    @property
    @pulumi.getter(name="oidcClientSecret")
    def oidc_client_secret(self) -> pulumi.Output[builtins.str]:
        """
        The secret for the Harbor client application.
        """
        return pulumi.get(self, "oidc_client_secret")

    @property
    @pulumi.getter(name="oidcEndpoint")
    def oidc_endpoint(self) -> pulumi.Output[builtins.str]:
        """
        The URL of an OIDC-compliant server.
        """
        return pulumi.get(self, "oidc_endpoint")

    @property
    @pulumi.getter(name="oidcGroupsClaim")
    def oidc_groups_claim(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The name of Claim in the ID token whose value is the list of group names.
        """
        return pulumi.get(self, "oidc_groups_claim")

    @property
    @pulumi.getter(name="oidcName")
    def oidc_name(self) -> pulumi.Output[builtins.str]:
        """
        The name of the OIDC provider.
        """
        return pulumi.get(self, "oidc_name")

    @property
    @pulumi.getter(name="oidcScope")
    def oidc_scope(self) -> pulumi.Output[builtins.str]:
        """
        The scope sent to OIDC server during authentication. It's a comma-separated string that must contain 'openid' and usually also contains 'profile' and 'email'. To obtain refresh tokens it should also contain 'offline_access'.
        """
        return pulumi.get(self, "oidc_scope")

    @property
    @pulumi.getter(name="oidcUserClaim")
    def oidc_user_claim(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The name of the claim in the ID Token where the username is retrieved from. If not specified, it will default to 'name' (only useful when automatic Onboarding is enabled).
        """
        return pulumi.get(self, "oidc_user_claim")

    @property
    @pulumi.getter(name="oidcVerifyCert")
    def oidc_verify_cert(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Set it to `false` if your OIDC server is hosted via self-signed certificate.
        """
        return pulumi.get(self, "oidc_verify_cert")

    @property
    @pulumi.getter(name="registryId")
    def registry_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the Managed Private Registry. **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "registry_id")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used. **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "service_name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetImagesResult',
    'AwaitableGetImagesResult',
    'get_images',
    'get_images_output',
]

@pulumi.output_type
class GetImagesResult:
    """
    A collection of values returned by getImages.
    """
    def __init__(__self__, flavor_type=None, id=None, images=None, os_type=None, region=None, service_name=None):
        if flavor_type and not isinstance(flavor_type, str):
            raise TypeError("Expected argument 'flavor_type' to be a str")
        pulumi.set(__self__, "flavor_type", flavor_type)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if images and not isinstance(images, list):
            raise TypeError("Expected argument 'images' to be a list")
        pulumi.set(__self__, "images", images)
        if os_type and not isinstance(os_type, str):
            raise TypeError("Expected argument 'os_type' to be a str")
        pulumi.set(__self__, "os_type", os_type)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)

    @property
    @pulumi.getter(name="flavorType")
    def flavor_type(self) -> builtins.str:
        """
        Get compatible images with flavor type
        """
        return pulumi.get(self, "flavor_type")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def images(self) -> Sequence['outputs.GetImagesImageResult']:
        return pulumi.get(self, "images")

    @property
    @pulumi.getter(name="osType")
    def os_type(self) -> builtins.str:
        """
        Image OS (Allowed values: baremetal-linux ┃ bsd ┃ linux ┃ windows)
        """
        return pulumi.get(self, "os_type")

    @property
    @pulumi.getter
    def region(self) -> builtins.str:
        """
        Image region
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        """
        Public cloud project ID
        """
        return pulumi.get(self, "service_name")


class AwaitableGetImagesResult(GetImagesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetImagesResult(
            flavor_type=self.flavor_type,
            id=self.id,
            images=self.images,
            os_type=self.os_type,
            region=self.region,
            service_name=self.service_name)


def get_images(flavor_type: Optional[builtins.str] = None,
               os_type: Optional[builtins.str] = None,
               region: Optional[builtins.str] = None,
               service_name: Optional[builtins.str] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetImagesResult:
    """
    Get available images in the given public cloud project.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    images = ovh.CloudProject.get_images(service_name="<public cloud project ID>",
        region="WAW1",
        os_type="linux")
    ```


    :param builtins.str flavor_type: Get compatible images with flavor type
    :param builtins.str os_type: Image OS (Allowed values: baremetal-linux ┃ bsd ┃ linux ┃ windows)
    :param builtins.str region: Image region
    :param builtins.str service_name: Public cloud project ID
    """
    __args__ = dict()
    __args__['flavorType'] = flavor_type
    __args__['osType'] = os_type
    __args__['region'] = region
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:CloudProject/getImages:getImages', __args__, opts=opts, typ=GetImagesResult).value

    return AwaitableGetImagesResult(
        flavor_type=pulumi.get(__ret__, 'flavor_type'),
        id=pulumi.get(__ret__, 'id'),
        images=pulumi.get(__ret__, 'images'),
        os_type=pulumi.get(__ret__, 'os_type'),
        region=pulumi.get(__ret__, 'region'),
        service_name=pulumi.get(__ret__, 'service_name'))
def get_images_output(flavor_type: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                      os_type: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                      region: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                      service_name: Optional[pulumi.Input[builtins.str]] = None,
                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetImagesResult]:
    """
    Get available images in the given public cloud project.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    images = ovh.CloudProject.get_images(service_name="<public cloud project ID>",
        region="WAW1",
        os_type="linux")
    ```


    :param builtins.str flavor_type: Get compatible images with flavor type
    :param builtins.str os_type: Image OS (Allowed values: baremetal-linux ┃ bsd ┃ linux ┃ windows)
    :param builtins.str region: Image region
    :param builtins.str service_name: Public cloud project ID
    """
    __args__ = dict()
    __args__['flavorType'] = flavor_type
    __args__['osType'] = os_type
    __args__['region'] = region
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:CloudProject/getImages:getImages', __args__, opts=opts, typ=GetImagesResult)
    return __ret__.apply(lambda __response__: GetImagesResult(
        flavor_type=pulumi.get(__response__, 'flavor_type'),
        id=pulumi.get(__response__, 'id'),
        images=pulumi.get(__response__, 'images'),
        os_type=pulumi.get(__response__, 'os_type'),
        region=pulumi.get(__response__, 'region'),
        service_name=pulumi.get(__response__, 'service_name')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetCephResult',
    'AwaitableGetCephResult',
    'get_ceph',
    'get_ceph_output',
]

@pulumi.output_type
class GetCephResult:
    """
    A collection of values returned by getCeph.
    """
    def __init__(__self__, ceph_urn=None, ceph_mons=None, ceph_version=None, crush_tunables=None, id=None, label=None, region=None, service_name=None, size=None, state=None, status=None):
        if ceph_urn and not isinstance(ceph_urn, str):
            raise TypeError("Expected argument 'ceph_urn' to be a str")
        pulumi.set(__self__, "ceph_urn", ceph_urn)
        if ceph_mons and not isinstance(ceph_mons, list):
            raise TypeError("Expected argument 'ceph_mons' to be a list")
        pulumi.set(__self__, "ceph_mons", ceph_mons)
        if ceph_version and not isinstance(ceph_version, str):
            raise TypeError("Expected argument 'ceph_version' to be a str")
        pulumi.set(__self__, "ceph_version", ceph_version)
        if crush_tunables and not isinstance(crush_tunables, str):
            raise TypeError("Expected argument 'crush_tunables' to be a str")
        pulumi.set(__self__, "crush_tunables", crush_tunables)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if label and not isinstance(label, str):
            raise TypeError("Expected argument 'label' to be a str")
        pulumi.set(__self__, "label", label)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if size and not isinstance(size, float):
            raise TypeError("Expected argument 'size' to be a float")
        pulumi.set(__self__, "size", size)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="CephURN")
    def ceph_urn(self) -> builtins.str:
        """
        URN of the CEPH instance
        """
        return pulumi.get(self, "ceph_urn")

    @property
    @pulumi.getter(name="cephMons")
    def ceph_mons(self) -> Sequence[builtins.str]:
        """
        list of CEPH monitors IPs
        """
        return pulumi.get(self, "ceph_mons")

    @property
    @pulumi.getter(name="cephVersion")
    def ceph_version(self) -> builtins.str:
        """
        CEPH cluster version
        """
        return pulumi.get(self, "ceph_version")

    @property
    @pulumi.getter(name="crushTunables")
    def crush_tunables(self) -> builtins.str:
        """
        CRUSH algorithm settings. Possible values
        * OPTIMAL
        * DEFAULT
        * LEGACY
        * BOBTAIL
        * ARGONAUT
        * FIREFLY
        * HAMMER
        * JEWEL
        """
        return pulumi.get(self, "crush_tunables")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def label(self) -> builtins.str:
        """
        CEPH cluster label
        """
        return pulumi.get(self, "label")

    @property
    @pulumi.getter
    def region(self) -> builtins.str:
        """
        cluster region
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def size(self) -> builtins.float:
        """
        Cluster size in TB
        """
        return pulumi.get(self, "size")

    @property
    @pulumi.getter
    def state(self) -> builtins.str:
        """
        the state of the cluster
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        the status of the service
        """
        return pulumi.get(self, "status")


class AwaitableGetCephResult(GetCephResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCephResult(
            ceph_urn=self.ceph_urn,
            ceph_mons=self.ceph_mons,
            ceph_version=self.ceph_version,
            crush_tunables=self.crush_tunables,
            id=self.id,
            label=self.label,
            region=self.region,
            service_name=self.service_name,
            size=self.size,
            state=self.state,
            status=self.status)


def get_ceph(ceph_version: Optional[builtins.str] = None,
             service_name: Optional[builtins.str] = None,
             status: Optional[builtins.str] = None,
             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCephResult:
    """
    Use this data source to retrieve information about a dedicated CEPH.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    my_ceph = ovh.Dedicated.get_ceph(service_name="XXXXXX")
    ```


    :param builtins.str ceph_version: CEPH cluster version
    :param builtins.str service_name: The service name of the dedicated CEPH cluster.
    :param builtins.str status: the status of the service
    """
    __args__ = dict()
    __args__['cephVersion'] = ceph_version
    __args__['serviceName'] = service_name
    __args__['status'] = status
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:Dedicated/getCeph:getCeph', __args__, opts=opts, typ=GetCephResult).value

    return AwaitableGetCephResult(
        ceph_urn=pulumi.get(__ret__, 'ceph_urn'),
        ceph_mons=pulumi.get(__ret__, 'ceph_mons'),
        ceph_version=pulumi.get(__ret__, 'ceph_version'),
        crush_tunables=pulumi.get(__ret__, 'crush_tunables'),
        id=pulumi.get(__ret__, 'id'),
        label=pulumi.get(__ret__, 'label'),
        region=pulumi.get(__ret__, 'region'),
        service_name=pulumi.get(__ret__, 'service_name'),
        size=pulumi.get(__ret__, 'size'),
        state=pulumi.get(__ret__, 'state'),
        status=pulumi.get(__ret__, 'status'))
def get_ceph_output(ceph_version: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                    service_name: Optional[pulumi.Input[builtins.str]] = None,
                    status: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetCephResult]:
    """
    Use this data source to retrieve information about a dedicated CEPH.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    my_ceph = ovh.Dedicated.get_ceph(service_name="XXXXXX")
    ```


    :param builtins.str ceph_version: CEPH cluster version
    :param builtins.str service_name: The service name of the dedicated CEPH cluster.
    :param builtins.str status: the status of the service
    """
    __args__ = dict()
    __args__['cephVersion'] = ceph_version
    __args__['serviceName'] = service_name
    __args__['status'] = status
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:Dedicated/getCeph:getCeph', __args__, opts=opts, typ=GetCephResult)
    return __ret__.apply(lambda __response__: GetCephResult(
        ceph_urn=pulumi.get(__response__, 'ceph_urn'),
        ceph_mons=pulumi.get(__response__, 'ceph_mons'),
        ceph_version=pulumi.get(__response__, 'ceph_version'),
        crush_tunables=pulumi.get(__response__, 'crush_tunables'),
        id=pulumi.get(__response__, 'id'),
        label=pulumi.get(__response__, 'label'),
        region=pulumi.get(__response__, 'region'),
        service_name=pulumi.get(__response__, 'service_name'),
        size=pulumi.get(__response__, 'size'),
        state=pulumi.get(__response__, 'state'),
        status=pulumi.get(__response__, 'status')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

import types

__config__ = pulumi.Config('ovh')


class _ExportableConfig(types.ModuleType):
    @property
    def access_token(self) -> Optional[str]:
        """
        The OVH API Access Token
        """
        return __config__.get('accessToken')

    @property
    def application_key(self) -> Optional[str]:
        """
        The OVH API Application Key
        """
        return __config__.get('applicationKey')

    @property
    def application_secret(self) -> Optional[str]:
        """
        The OVH API Application Secret
        """
        return __config__.get('applicationSecret')

    @property
    def client_id(self) -> Optional[str]:
        """
        OAuth 2.0 application's ID
        """
        return __config__.get('clientId')

    @property
    def client_secret(self) -> Optional[str]:
        """
        OAuth 2.0 application's secret
        """
        return __config__.get('clientSecret')

    @property
    def consumer_key(self) -> Optional[str]:
        """
        The OVH API Consumer Key
        """
        return __config__.get('consumerKey')

    @property
    def endpoint(self) -> Optional[str]:
        """
        The OVH API endpoint to target (ex: "ovh-eu")
        """
        return __config__.get('endpoint')




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['LoadBalancerArgs', 'LoadBalancer']

@pulumi.input_type
class LoadBalancerArgs:
    def __init__(__self__, *,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 orders: Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerOrderArgs']]]] = None,
                 ovh_subsidiary: Optional[pulumi.Input[builtins.str]] = None,
                 payment_mean: Optional[pulumi.Input[builtins.str]] = None,
                 plan: Optional[pulumi.Input['LoadBalancerPlanArgs']] = None,
                 plan_options: Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerPlanOptionArgs']]]] = None,
                 ssl_configuration: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a LoadBalancer resource.
        :param pulumi.Input[builtins.str] display_name: Set the name displayed in ManagerV6 for your iplb (max 50 chars)
        :param pulumi.Input[Sequence[pulumi.Input['LoadBalancerOrderArgs']]] orders: Details about an Order
        :param pulumi.Input[builtins.str] ovh_subsidiary: OVHcloud Subsidiary. Country of OVHcloud legal entity you'll be billed by. List of supported subsidiaries available on API at [/1.0/me.json under `models.nichandle.OvhSubsidiaryEnum`](https://eu.api.ovh.com/1.0/me.json)
        :param pulumi.Input[builtins.str] payment_mean: Ovh payment mode
        :param pulumi.Input['LoadBalancerPlanArgs'] plan: Product Plan to order
        :param pulumi.Input[Sequence[pulumi.Input['LoadBalancerPlanOptionArgs']]] plan_options: Product Plan to order
        :param pulumi.Input[builtins.str] ssl_configuration: Modern oldest compatible clients : Firefox 27, Chrome 30, IE 11 on Windows 7, Edge, Opera 17, Safari 9, Android 5.0, and Java 8. Intermediate oldest compatible clients : Firefox 1, Chrome 1, IE 7, Opera 5, Safari 1, Windows XP IE8, Android 2.3, Java 7. Intermediate if null. one of "intermediate", "modern".
        """
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if orders is not None:
            pulumi.set(__self__, "orders", orders)
        if ovh_subsidiary is not None:
            pulumi.set(__self__, "ovh_subsidiary", ovh_subsidiary)
        if payment_mean is not None:
            warnings.warn("""This field is not anymore used since the API has been deprecated in favor of /payment/mean. Now, the default payment mean is used.""", DeprecationWarning)
            pulumi.log.warn("""payment_mean is deprecated: This field is not anymore used since the API has been deprecated in favor of /payment/mean. Now, the default payment mean is used.""")
        if payment_mean is not None:
            pulumi.set(__self__, "payment_mean", payment_mean)
        if plan is not None:
            pulumi.set(__self__, "plan", plan)
        if plan_options is not None:
            pulumi.set(__self__, "plan_options", plan_options)
        if ssl_configuration is not None:
            pulumi.set(__self__, "ssl_configuration", ssl_configuration)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Set the name displayed in ManagerV6 for your iplb (max 50 chars)
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter
    def orders(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerOrderArgs']]]]:
        """
        Details about an Order
        """
        return pulumi.get(self, "orders")

    @orders.setter
    def orders(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerOrderArgs']]]]):
        pulumi.set(self, "orders", value)

    @property
    @pulumi.getter(name="ovhSubsidiary")
    def ovh_subsidiary(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        OVHcloud Subsidiary. Country of OVHcloud legal entity you'll be billed by. List of supported subsidiaries available on API at [/1.0/me.json under `models.nichandle.OvhSubsidiaryEnum`](https://eu.api.ovh.com/1.0/me.json)
        """
        return pulumi.get(self, "ovh_subsidiary")

    @ovh_subsidiary.setter
    def ovh_subsidiary(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ovh_subsidiary", value)

    @property
    @pulumi.getter(name="paymentMean")
    @_utilities.deprecated("""This field is not anymore used since the API has been deprecated in favor of /payment/mean. Now, the default payment mean is used.""")
    def payment_mean(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Ovh payment mode
        """
        return pulumi.get(self, "payment_mean")

    @payment_mean.setter
    def payment_mean(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "payment_mean", value)

    @property
    @pulumi.getter
    def plan(self) -> Optional[pulumi.Input['LoadBalancerPlanArgs']]:
        """
        Product Plan to order
        """
        return pulumi.get(self, "plan")

    @plan.setter
    def plan(self, value: Optional[pulumi.Input['LoadBalancerPlanArgs']]):
        pulumi.set(self, "plan", value)

    @property
    @pulumi.getter(name="planOptions")
    def plan_options(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerPlanOptionArgs']]]]:
        """
        Product Plan to order
        """
        return pulumi.get(self, "plan_options")

    @plan_options.setter
    def plan_options(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerPlanOptionArgs']]]]):
        pulumi.set(self, "plan_options", value)

    @property
    @pulumi.getter(name="sslConfiguration")
    def ssl_configuration(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Modern oldest compatible clients : Firefox 27, Chrome 30, IE 11 on Windows 7, Edge, Opera 17, Safari 9, Android 5.0, and Java 8. Intermediate oldest compatible clients : Firefox 1, Chrome 1, IE 7, Opera 5, Safari 1, Windows XP IE8, Android 2.3, Java 7. Intermediate if null. one of "intermediate", "modern".
        """
        return pulumi.get(self, "ssl_configuration")

    @ssl_configuration.setter
    def ssl_configuration(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ssl_configuration", value)


@pulumi.input_type
class _LoadBalancerState:
    def __init__(__self__, *,
                 load_balancer_urn: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 ip_loadbalancing: Optional[pulumi.Input[builtins.str]] = None,
                 ipv4: Optional[pulumi.Input[builtins.str]] = None,
                 ipv6: Optional[pulumi.Input[builtins.str]] = None,
                 metrics_token: Optional[pulumi.Input[builtins.str]] = None,
                 offer: Optional[pulumi.Input[builtins.str]] = None,
                 orderable_zones: Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerOrderableZoneArgs']]]] = None,
                 orders: Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerOrderArgs']]]] = None,
                 ovh_subsidiary: Optional[pulumi.Input[builtins.str]] = None,
                 payment_mean: Optional[pulumi.Input[builtins.str]] = None,
                 plan: Optional[pulumi.Input['LoadBalancerPlanArgs']] = None,
                 plan_options: Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerPlanOptionArgs']]]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 ssl_configuration: Optional[pulumi.Input[builtins.str]] = None,
                 state: Optional[pulumi.Input[builtins.str]] = None,
                 vrack_eligibility: Optional[pulumi.Input[builtins.bool]] = None,
                 vrack_name: Optional[pulumi.Input[builtins.str]] = None,
                 zones: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering LoadBalancer resources.
        :param pulumi.Input[builtins.str] load_balancer_urn: URN of the load balancer, used when writing IAM policies
        :param pulumi.Input[builtins.str] display_name: Set the name displayed in ManagerV6 for your iplb (max 50 chars)
        :param pulumi.Input[builtins.str] ip_loadbalancing: Your IP load balancing
        :param pulumi.Input[builtins.str] ipv4: The IPV4 associated to your IP load balancing
        :param pulumi.Input[builtins.str] ipv6: The IPV6 associated to your IP load balancing. DEPRECATED.
        :param pulumi.Input[builtins.str] metrics_token: The metrics token associated with your IP load balancing
        :param pulumi.Input[builtins.str] offer: The offer of your IP load balancing
        :param pulumi.Input[Sequence[pulumi.Input['LoadBalancerOrderableZoneArgs']]] orderable_zones: Available additional zone for your Load Balancer
        :param pulumi.Input[Sequence[pulumi.Input['LoadBalancerOrderArgs']]] orders: Details about an Order
        :param pulumi.Input[builtins.str] ovh_subsidiary: OVHcloud Subsidiary. Country of OVHcloud legal entity you'll be billed by. List of supported subsidiaries available on API at [/1.0/me.json under `models.nichandle.OvhSubsidiaryEnum`](https://eu.api.ovh.com/1.0/me.json)
        :param pulumi.Input[builtins.str] payment_mean: Ovh payment mode
        :param pulumi.Input['LoadBalancerPlanArgs'] plan: Product Plan to order
        :param pulumi.Input[Sequence[pulumi.Input['LoadBalancerPlanOptionArgs']]] plan_options: Product Plan to order
        :param pulumi.Input[builtins.str] service_name: The internal name of your IP load balancing
        :param pulumi.Input[builtins.str] ssl_configuration: Modern oldest compatible clients : Firefox 27, Chrome 30, IE 11 on Windows 7, Edge, Opera 17, Safari 9, Android 5.0, and Java 8. Intermediate oldest compatible clients : Firefox 1, Chrome 1, IE 7, Opera 5, Safari 1, Windows XP IE8, Android 2.3, Java 7. Intermediate if null. one of "intermediate", "modern".
        :param pulumi.Input[builtins.str] state: Current state of your IP
        :param pulumi.Input[builtins.bool] vrack_eligibility: Vrack eligibility
        :param pulumi.Input[builtins.str] vrack_name: Name of the vRack on which the current Load Balancer is attached to, as it is named on vRack product
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] zones: Location where your service is
        """
        if load_balancer_urn is not None:
            pulumi.set(__self__, "load_balancer_urn", load_balancer_urn)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if ip_loadbalancing is not None:
            pulumi.set(__self__, "ip_loadbalancing", ip_loadbalancing)
        if ipv4 is not None:
            pulumi.set(__self__, "ipv4", ipv4)
        if ipv6 is not None:
            pulumi.set(__self__, "ipv6", ipv6)
        if metrics_token is not None:
            pulumi.set(__self__, "metrics_token", metrics_token)
        if offer is not None:
            pulumi.set(__self__, "offer", offer)
        if orderable_zones is not None:
            pulumi.set(__self__, "orderable_zones", orderable_zones)
        if orders is not None:
            pulumi.set(__self__, "orders", orders)
        if ovh_subsidiary is not None:
            pulumi.set(__self__, "ovh_subsidiary", ovh_subsidiary)
        if payment_mean is not None:
            warnings.warn("""This field is not anymore used since the API has been deprecated in favor of /payment/mean. Now, the default payment mean is used.""", DeprecationWarning)
            pulumi.log.warn("""payment_mean is deprecated: This field is not anymore used since the API has been deprecated in favor of /payment/mean. Now, the default payment mean is used.""")
        if payment_mean is not None:
            pulumi.set(__self__, "payment_mean", payment_mean)
        if plan is not None:
            pulumi.set(__self__, "plan", plan)
        if plan_options is not None:
            pulumi.set(__self__, "plan_options", plan_options)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if ssl_configuration is not None:
            pulumi.set(__self__, "ssl_configuration", ssl_configuration)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if vrack_eligibility is not None:
            pulumi.set(__self__, "vrack_eligibility", vrack_eligibility)
        if vrack_name is not None:
            pulumi.set(__self__, "vrack_name", vrack_name)
        if zones is not None:
            pulumi.set(__self__, "zones", zones)

    @property
    @pulumi.getter(name="LoadBalancerURN")
    def load_balancer_urn(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        URN of the load balancer, used when writing IAM policies
        """
        return pulumi.get(self, "load_balancer_urn")

    @load_balancer_urn.setter
    def load_balancer_urn(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "load_balancer_urn", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Set the name displayed in ManagerV6 for your iplb (max 50 chars)
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="ipLoadbalancing")
    def ip_loadbalancing(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Your IP load balancing
        """
        return pulumi.get(self, "ip_loadbalancing")

    @ip_loadbalancing.setter
    def ip_loadbalancing(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip_loadbalancing", value)

    @property
    @pulumi.getter
    def ipv4(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The IPV4 associated to your IP load balancing
        """
        return pulumi.get(self, "ipv4")

    @ipv4.setter
    def ipv4(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ipv4", value)

    @property
    @pulumi.getter
    def ipv6(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The IPV6 associated to your IP load balancing. DEPRECATED.
        """
        return pulumi.get(self, "ipv6")

    @ipv6.setter
    def ipv6(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ipv6", value)

    @property
    @pulumi.getter(name="metricsToken")
    def metrics_token(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The metrics token associated with your IP load balancing
        """
        return pulumi.get(self, "metrics_token")

    @metrics_token.setter
    def metrics_token(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "metrics_token", value)

    @property
    @pulumi.getter
    def offer(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The offer of your IP load balancing
        """
        return pulumi.get(self, "offer")

    @offer.setter
    def offer(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "offer", value)

    @property
    @pulumi.getter(name="orderableZones")
    def orderable_zones(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerOrderableZoneArgs']]]]:
        """
        Available additional zone for your Load Balancer
        """
        return pulumi.get(self, "orderable_zones")

    @orderable_zones.setter
    def orderable_zones(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerOrderableZoneArgs']]]]):
        pulumi.set(self, "orderable_zones", value)

    @property
    @pulumi.getter
    def orders(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerOrderArgs']]]]:
        """
        Details about an Order
        """
        return pulumi.get(self, "orders")

    @orders.setter
    def orders(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerOrderArgs']]]]):
        pulumi.set(self, "orders", value)

    @property
    @pulumi.getter(name="ovhSubsidiary")
    def ovh_subsidiary(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        OVHcloud Subsidiary. Country of OVHcloud legal entity you'll be billed by. List of supported subsidiaries available on API at [/1.0/me.json under `models.nichandle.OvhSubsidiaryEnum`](https://eu.api.ovh.com/1.0/me.json)
        """
        return pulumi.get(self, "ovh_subsidiary")

    @ovh_subsidiary.setter
    def ovh_subsidiary(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ovh_subsidiary", value)

    @property
    @pulumi.getter(name="paymentMean")
    @_utilities.deprecated("""This field is not anymore used since the API has been deprecated in favor of /payment/mean. Now, the default payment mean is used.""")
    def payment_mean(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Ovh payment mode
        """
        return pulumi.get(self, "payment_mean")

    @payment_mean.setter
    def payment_mean(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "payment_mean", value)

    @property
    @pulumi.getter
    def plan(self) -> Optional[pulumi.Input['LoadBalancerPlanArgs']]:
        """
        Product Plan to order
        """
        return pulumi.get(self, "plan")

    @plan.setter
    def plan(self, value: Optional[pulumi.Input['LoadBalancerPlanArgs']]):
        pulumi.set(self, "plan", value)

    @property
    @pulumi.getter(name="planOptions")
    def plan_options(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerPlanOptionArgs']]]]:
        """
        Product Plan to order
        """
        return pulumi.get(self, "plan_options")

    @plan_options.setter
    def plan_options(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerPlanOptionArgs']]]]):
        pulumi.set(self, "plan_options", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The internal name of your IP load balancing
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter(name="sslConfiguration")
    def ssl_configuration(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Modern oldest compatible clients : Firefox 27, Chrome 30, IE 11 on Windows 7, Edge, Opera 17, Safari 9, Android 5.0, and Java 8. Intermediate oldest compatible clients : Firefox 1, Chrome 1, IE 7, Opera 5, Safari 1, Windows XP IE8, Android 2.3, Java 7. Intermediate if null. one of "intermediate", "modern".
        """
        return pulumi.get(self, "ssl_configuration")

    @ssl_configuration.setter
    def ssl_configuration(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ssl_configuration", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Current state of your IP
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "state", value)

    @property
    @pulumi.getter(name="vrackEligibility")
    def vrack_eligibility(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Vrack eligibility
        """
        return pulumi.get(self, "vrack_eligibility")

    @vrack_eligibility.setter
    def vrack_eligibility(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "vrack_eligibility", value)

    @property
    @pulumi.getter(name="vrackName")
    def vrack_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Name of the vRack on which the current Load Balancer is attached to, as it is named on vRack product
        """
        return pulumi.get(self, "vrack_name")

    @vrack_name.setter
    def vrack_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vrack_name", value)

    @property
    @pulumi.getter
    def zones(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        Location where your service is
        """
        return pulumi.get(self, "zones")

    @zones.setter
    def zones(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "zones", value)


class LoadBalancer(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 orders: Optional[pulumi.Input[Sequence[pulumi.Input[Union['LoadBalancerOrderArgs', 'LoadBalancerOrderArgsDict']]]]] = None,
                 ovh_subsidiary: Optional[pulumi.Input[builtins.str]] = None,
                 payment_mean: Optional[pulumi.Input[builtins.str]] = None,
                 plan: Optional[pulumi.Input[Union['LoadBalancerPlanArgs', 'LoadBalancerPlanArgsDict']]] = None,
                 plan_options: Optional[pulumi.Input[Sequence[pulumi.Input[Union['LoadBalancerPlanOptionArgs', 'LoadBalancerPlanOptionArgsDict']]]]] = None,
                 ssl_configuration: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        myaccount = ovh.Me.get_me()
        mycart = ovh.Order.get_cart(ovh_subsidiary=myaccount.ovh_subsidiary)
        iplb = ovh.Order.get_cart_product_plan(cart_id=mycart.id,
            price_capacity="renew",
            product="ipLoadbalancing",
            plan_code="iplb-lb1")
        bhs = ovh.Order.get_cart_product_options_plan(cart_id=iplb.cart_id,
            price_capacity=iplb.price_capacity,
            product=iplb.product,
            plan_code=iplb.plan_code,
            options_plan_code="iplb-zone-lb1-rbx")
        iplb_lb1 = ovh.ip_load_balancing.LoadBalancer("iplb-lb1",
            ovh_subsidiary=mycart.ovh_subsidiary,
            display_name="my ip loadbalancing",
            plan={
                "duration": iplb.selected_prices[0].duration,
                "plan_code": iplb.plan_code,
                "pricing_mode": iplb.selected_prices[0].pricing_mode,
            },
            plan_options=[{
                "duration": bhs.selected_prices[0].duration,
                "plan_code": bhs.plan_code,
                "pricing_mode": bhs.selected_prices[0].pricing_mode,
            }])
        ```

        ## Import

        OVHcloud IP load balancing services can be imported using its `service_name`.

        Using the following configuration:

        terraform

        import {

          to = ovh_iploadbalancing.iplb

          id = "<service name>"

        }

        You can then run:

        bash

        $ pulumi preview -generate-config-out=iplb.tf

        $ pulumi up

        The file `iplb.tf` will then contain the imported resource's configuration, that can be copied next to the `import` block above. See https://developer.hashicorp.com/terraform/language/import/generating-configuration for more details.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] display_name: Set the name displayed in ManagerV6 for your iplb (max 50 chars)
        :param pulumi.Input[Sequence[pulumi.Input[Union['LoadBalancerOrderArgs', 'LoadBalancerOrderArgsDict']]]] orders: Details about an Order
        :param pulumi.Input[builtins.str] ovh_subsidiary: OVHcloud Subsidiary. Country of OVHcloud legal entity you'll be billed by. List of supported subsidiaries available on API at [/1.0/me.json under `models.nichandle.OvhSubsidiaryEnum`](https://eu.api.ovh.com/1.0/me.json)
        :param pulumi.Input[builtins.str] payment_mean: Ovh payment mode
        :param pulumi.Input[Union['LoadBalancerPlanArgs', 'LoadBalancerPlanArgsDict']] plan: Product Plan to order
        :param pulumi.Input[Sequence[pulumi.Input[Union['LoadBalancerPlanOptionArgs', 'LoadBalancerPlanOptionArgsDict']]]] plan_options: Product Plan to order
        :param pulumi.Input[builtins.str] ssl_configuration: Modern oldest compatible clients : Firefox 27, Chrome 30, IE 11 on Windows 7, Edge, Opera 17, Safari 9, Android 5.0, and Java 8. Intermediate oldest compatible clients : Firefox 1, Chrome 1, IE 7, Opera 5, Safari 1, Windows XP IE8, Android 2.3, Java 7. Intermediate if null. one of "intermediate", "modern".
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[LoadBalancerArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        myaccount = ovh.Me.get_me()
        mycart = ovh.Order.get_cart(ovh_subsidiary=myaccount.ovh_subsidiary)
        iplb = ovh.Order.get_cart_product_plan(cart_id=mycart.id,
            price_capacity="renew",
            product="ipLoadbalancing",
            plan_code="iplb-lb1")
        bhs = ovh.Order.get_cart_product_options_plan(cart_id=iplb.cart_id,
            price_capacity=iplb.price_capacity,
            product=iplb.product,
            plan_code=iplb.plan_code,
            options_plan_code="iplb-zone-lb1-rbx")
        iplb_lb1 = ovh.ip_load_balancing.LoadBalancer("iplb-lb1",
            ovh_subsidiary=mycart.ovh_subsidiary,
            display_name="my ip loadbalancing",
            plan={
                "duration": iplb.selected_prices[0].duration,
                "plan_code": iplb.plan_code,
                "pricing_mode": iplb.selected_prices[0].pricing_mode,
            },
            plan_options=[{
                "duration": bhs.selected_prices[0].duration,
                "plan_code": bhs.plan_code,
                "pricing_mode": bhs.selected_prices[0].pricing_mode,
            }])
        ```

        ## Import

        OVHcloud IP load balancing services can be imported using its `service_name`.

        Using the following configuration:

        terraform

        import {

          to = ovh_iploadbalancing.iplb

          id = "<service name>"

        }

        You can then run:

        bash

        $ pulumi preview -generate-config-out=iplb.tf

        $ pulumi up

        The file `iplb.tf` will then contain the imported resource's configuration, that can be copied next to the `import` block above. See https://developer.hashicorp.com/terraform/language/import/generating-configuration for more details.

        :param str resource_name: The name of the resource.
        :param LoadBalancerArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(LoadBalancerArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 orders: Optional[pulumi.Input[Sequence[pulumi.Input[Union['LoadBalancerOrderArgs', 'LoadBalancerOrderArgsDict']]]]] = None,
                 ovh_subsidiary: Optional[pulumi.Input[builtins.str]] = None,
                 payment_mean: Optional[pulumi.Input[builtins.str]] = None,
                 plan: Optional[pulumi.Input[Union['LoadBalancerPlanArgs', 'LoadBalancerPlanArgsDict']]] = None,
                 plan_options: Optional[pulumi.Input[Sequence[pulumi.Input[Union['LoadBalancerPlanOptionArgs', 'LoadBalancerPlanOptionArgsDict']]]]] = None,
                 ssl_configuration: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = LoadBalancerArgs.__new__(LoadBalancerArgs)

            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["orders"] = orders
            __props__.__dict__["ovh_subsidiary"] = ovh_subsidiary
            __props__.__dict__["payment_mean"] = payment_mean
            __props__.__dict__["plan"] = plan
            __props__.__dict__["plan_options"] = plan_options
            __props__.__dict__["ssl_configuration"] = ssl_configuration
            __props__.__dict__["load_balancer_urn"] = None
            __props__.__dict__["ip_loadbalancing"] = None
            __props__.__dict__["ipv4"] = None
            __props__.__dict__["ipv6"] = None
            __props__.__dict__["metrics_token"] = None
            __props__.__dict__["offer"] = None
            __props__.__dict__["orderable_zones"] = None
            __props__.__dict__["service_name"] = None
            __props__.__dict__["state"] = None
            __props__.__dict__["vrack_eligibility"] = None
            __props__.__dict__["vrack_name"] = None
            __props__.__dict__["zones"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["metricsToken"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(LoadBalancer, __self__).__init__(
            'ovh:IpLoadBalancing/loadBalancer:LoadBalancer',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            load_balancer_urn: Optional[pulumi.Input[builtins.str]] = None,
            display_name: Optional[pulumi.Input[builtins.str]] = None,
            ip_loadbalancing: Optional[pulumi.Input[builtins.str]] = None,
            ipv4: Optional[pulumi.Input[builtins.str]] = None,
            ipv6: Optional[pulumi.Input[builtins.str]] = None,
            metrics_token: Optional[pulumi.Input[builtins.str]] = None,
            offer: Optional[pulumi.Input[builtins.str]] = None,
            orderable_zones: Optional[pulumi.Input[Sequence[pulumi.Input[Union['LoadBalancerOrderableZoneArgs', 'LoadBalancerOrderableZoneArgsDict']]]]] = None,
            orders: Optional[pulumi.Input[Sequence[pulumi.Input[Union['LoadBalancerOrderArgs', 'LoadBalancerOrderArgsDict']]]]] = None,
            ovh_subsidiary: Optional[pulumi.Input[builtins.str]] = None,
            payment_mean: Optional[pulumi.Input[builtins.str]] = None,
            plan: Optional[pulumi.Input[Union['LoadBalancerPlanArgs', 'LoadBalancerPlanArgsDict']]] = None,
            plan_options: Optional[pulumi.Input[Sequence[pulumi.Input[Union['LoadBalancerPlanOptionArgs', 'LoadBalancerPlanOptionArgsDict']]]]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None,
            ssl_configuration: Optional[pulumi.Input[builtins.str]] = None,
            state: Optional[pulumi.Input[builtins.str]] = None,
            vrack_eligibility: Optional[pulumi.Input[builtins.bool]] = None,
            vrack_name: Optional[pulumi.Input[builtins.str]] = None,
            zones: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None) -> 'LoadBalancer':
        """
        Get an existing LoadBalancer resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] load_balancer_urn: URN of the load balancer, used when writing IAM policies
        :param pulumi.Input[builtins.str] display_name: Set the name displayed in ManagerV6 for your iplb (max 50 chars)
        :param pulumi.Input[builtins.str] ip_loadbalancing: Your IP load balancing
        :param pulumi.Input[builtins.str] ipv4: The IPV4 associated to your IP load balancing
        :param pulumi.Input[builtins.str] ipv6: The IPV6 associated to your IP load balancing. DEPRECATED.
        :param pulumi.Input[builtins.str] metrics_token: The metrics token associated with your IP load balancing
        :param pulumi.Input[builtins.str] offer: The offer of your IP load balancing
        :param pulumi.Input[Sequence[pulumi.Input[Union['LoadBalancerOrderableZoneArgs', 'LoadBalancerOrderableZoneArgsDict']]]] orderable_zones: Available additional zone for your Load Balancer
        :param pulumi.Input[Sequence[pulumi.Input[Union['LoadBalancerOrderArgs', 'LoadBalancerOrderArgsDict']]]] orders: Details about an Order
        :param pulumi.Input[builtins.str] ovh_subsidiary: OVHcloud Subsidiary. Country of OVHcloud legal entity you'll be billed by. List of supported subsidiaries available on API at [/1.0/me.json under `models.nichandle.OvhSubsidiaryEnum`](https://eu.api.ovh.com/1.0/me.json)
        :param pulumi.Input[builtins.str] payment_mean: Ovh payment mode
        :param pulumi.Input[Union['LoadBalancerPlanArgs', 'LoadBalancerPlanArgsDict']] plan: Product Plan to order
        :param pulumi.Input[Sequence[pulumi.Input[Union['LoadBalancerPlanOptionArgs', 'LoadBalancerPlanOptionArgsDict']]]] plan_options: Product Plan to order
        :param pulumi.Input[builtins.str] service_name: The internal name of your IP load balancing
        :param pulumi.Input[builtins.str] ssl_configuration: Modern oldest compatible clients : Firefox 27, Chrome 30, IE 11 on Windows 7, Edge, Opera 17, Safari 9, Android 5.0, and Java 8. Intermediate oldest compatible clients : Firefox 1, Chrome 1, IE 7, Opera 5, Safari 1, Windows XP IE8, Android 2.3, Java 7. Intermediate if null. one of "intermediate", "modern".
        :param pulumi.Input[builtins.str] state: Current state of your IP
        :param pulumi.Input[builtins.bool] vrack_eligibility: Vrack eligibility
        :param pulumi.Input[builtins.str] vrack_name: Name of the vRack on which the current Load Balancer is attached to, as it is named on vRack product
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] zones: Location where your service is
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _LoadBalancerState.__new__(_LoadBalancerState)

        __props__.__dict__["load_balancer_urn"] = load_balancer_urn
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["ip_loadbalancing"] = ip_loadbalancing
        __props__.__dict__["ipv4"] = ipv4
        __props__.__dict__["ipv6"] = ipv6
        __props__.__dict__["metrics_token"] = metrics_token
        __props__.__dict__["offer"] = offer
        __props__.__dict__["orderable_zones"] = orderable_zones
        __props__.__dict__["orders"] = orders
        __props__.__dict__["ovh_subsidiary"] = ovh_subsidiary
        __props__.__dict__["payment_mean"] = payment_mean
        __props__.__dict__["plan"] = plan
        __props__.__dict__["plan_options"] = plan_options
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["ssl_configuration"] = ssl_configuration
        __props__.__dict__["state"] = state
        __props__.__dict__["vrack_eligibility"] = vrack_eligibility
        __props__.__dict__["vrack_name"] = vrack_name
        __props__.__dict__["zones"] = zones
        return LoadBalancer(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="LoadBalancerURN")
    def load_balancer_urn(self) -> pulumi.Output[builtins.str]:
        """
        URN of the load balancer, used when writing IAM policies
        """
        return pulumi.get(self, "load_balancer_urn")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[builtins.str]:
        """
        Set the name displayed in ManagerV6 for your iplb (max 50 chars)
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="ipLoadbalancing")
    def ip_loadbalancing(self) -> pulumi.Output[builtins.str]:
        """
        Your IP load balancing
        """
        return pulumi.get(self, "ip_loadbalancing")

    @property
    @pulumi.getter
    def ipv4(self) -> pulumi.Output[builtins.str]:
        """
        The IPV4 associated to your IP load balancing
        """
        return pulumi.get(self, "ipv4")

    @property
    @pulumi.getter
    def ipv6(self) -> pulumi.Output[builtins.str]:
        """
        The IPV6 associated to your IP load balancing. DEPRECATED.
        """
        return pulumi.get(self, "ipv6")

    @property
    @pulumi.getter(name="metricsToken")
    def metrics_token(self) -> pulumi.Output[builtins.str]:
        """
        The metrics token associated with your IP load balancing
        """
        return pulumi.get(self, "metrics_token")

    @property
    @pulumi.getter
    def offer(self) -> pulumi.Output[builtins.str]:
        """
        The offer of your IP load balancing
        """
        return pulumi.get(self, "offer")

    @property
    @pulumi.getter(name="orderableZones")
    def orderable_zones(self) -> pulumi.Output[Sequence['outputs.LoadBalancerOrderableZone']]:
        """
        Available additional zone for your Load Balancer
        """
        return pulumi.get(self, "orderable_zones")

    @property
    @pulumi.getter
    def orders(self) -> pulumi.Output[Sequence['outputs.LoadBalancerOrder']]:
        """
        Details about an Order
        """
        return pulumi.get(self, "orders")

    @property
    @pulumi.getter(name="ovhSubsidiary")
    def ovh_subsidiary(self) -> pulumi.Output[builtins.str]:
        """
        OVHcloud Subsidiary. Country of OVHcloud legal entity you'll be billed by. List of supported subsidiaries available on API at [/1.0/me.json under `models.nichandle.OvhSubsidiaryEnum`](https://eu.api.ovh.com/1.0/me.json)
        """
        return pulumi.get(self, "ovh_subsidiary")

    @property
    @pulumi.getter(name="paymentMean")
    @_utilities.deprecated("""This field is not anymore used since the API has been deprecated in favor of /payment/mean. Now, the default payment mean is used.""")
    def payment_mean(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Ovh payment mode
        """
        return pulumi.get(self, "payment_mean")

    @property
    @pulumi.getter
    def plan(self) -> pulumi.Output['outputs.LoadBalancerPlan']:
        """
        Product Plan to order
        """
        return pulumi.get(self, "plan")

    @property
    @pulumi.getter(name="planOptions")
    def plan_options(self) -> pulumi.Output[Optional[Sequence['outputs.LoadBalancerPlanOption']]]:
        """
        Product Plan to order
        """
        return pulumi.get(self, "plan_options")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        The internal name of your IP load balancing
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter(name="sslConfiguration")
    def ssl_configuration(self) -> pulumi.Output[builtins.str]:
        """
        Modern oldest compatible clients : Firefox 27, Chrome 30, IE 11 on Windows 7, Edge, Opera 17, Safari 9, Android 5.0, and Java 8. Intermediate oldest compatible clients : Firefox 1, Chrome 1, IE 7, Opera 5, Safari 1, Windows XP IE8, Android 2.3, Java 7. Intermediate if null. one of "intermediate", "modern".
        """
        return pulumi.get(self, "ssl_configuration")

    @property
    @pulumi.getter
    def state(self) -> pulumi.Output[builtins.str]:
        """
        Current state of your IP
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="vrackEligibility")
    def vrack_eligibility(self) -> pulumi.Output[builtins.bool]:
        """
        Vrack eligibility
        """
        return pulumi.get(self, "vrack_eligibility")

    @property
    @pulumi.getter(name="vrackName")
    def vrack_name(self) -> pulumi.Output[builtins.str]:
        """
        Name of the vRack on which the current Load Balancer is attached to, as it is named on vRack product
        """
        return pulumi.get(self, "vrack_name")

    @property
    @pulumi.getter
    def zones(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        Location where your service is
        """
        return pulumi.get(self, "zones")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetPermissionsGroupResult',
    'AwaitableGetPermissionsGroupResult',
    'get_permissions_group',
    'get_permissions_group_output',
]

@pulumi.output_type
class GetPermissionsGroupResult:
    """
    A collection of values returned by getPermissionsGroup.
    """
    def __init__(__self__, allows=None, created_at=None, denies=None, description=None, excepts=None, id=None, name=None, owner=None, updated_at=None, urn=None):
        if allows and not isinstance(allows, list):
            raise TypeError("Expected argument 'allows' to be a list")
        pulumi.set(__self__, "allows", allows)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if denies and not isinstance(denies, list):
            raise TypeError("Expected argument 'denies' to be a list")
        pulumi.set(__self__, "denies", denies)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if excepts and not isinstance(excepts, list):
            raise TypeError("Expected argument 'excepts' to be a list")
        pulumi.set(__self__, "excepts", excepts)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if owner and not isinstance(owner, str):
            raise TypeError("Expected argument 'owner' to be a str")
        pulumi.set(__self__, "owner", owner)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)
        if urn and not isinstance(urn, str):
            raise TypeError("Expected argument 'urn' to be a str")
        pulumi.set(__self__, "urn", urn)

    @property
    @pulumi.getter
    def allows(self) -> Optional[Sequence[builtins.str]]:
        return pulumi.get(self, "allows")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> builtins.str:
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def denies(self) -> Optional[Sequence[builtins.str]]:
        return pulumi.get(self, "denies")

    @property
    @pulumi.getter
    def description(self) -> Optional[builtins.str]:
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def excepts(self) -> Optional[Sequence[builtins.str]]:
        return pulumi.get(self, "excepts")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The ID of this resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def owner(self) -> builtins.str:
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> builtins.str:
        return pulumi.get(self, "updated_at")

    @property
    @pulumi.getter
    def urn(self) -> builtins.str:
        return pulumi.get(self, "urn")


class AwaitableGetPermissionsGroupResult(GetPermissionsGroupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPermissionsGroupResult(
            allows=self.allows,
            created_at=self.created_at,
            denies=self.denies,
            description=self.description,
            excepts=self.excepts,
            id=self.id,
            name=self.name,
            owner=self.owner,
            updated_at=self.updated_at,
            urn=self.urn)


def get_permissions_group(allows: Optional[Sequence[builtins.str]] = None,
                          denies: Optional[Sequence[builtins.str]] = None,
                          description: Optional[builtins.str] = None,
                          excepts: Optional[Sequence[builtins.str]] = None,
                          updated_at: Optional[builtins.str] = None,
                          urn: Optional[builtins.str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPermissionsGroupResult:
    """
    Use this data source to access information about an existing resource.
    """
    __args__ = dict()
    __args__['allows'] = allows
    __args__['denies'] = denies
    __args__['description'] = description
    __args__['excepts'] = excepts
    __args__['updatedAt'] = updated_at
    __args__['urn'] = urn
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:Iam/getPermissionsGroup:getPermissionsGroup', __args__, opts=opts, typ=GetPermissionsGroupResult).value

    return AwaitableGetPermissionsGroupResult(
        allows=pulumi.get(__ret__, 'allows'),
        created_at=pulumi.get(__ret__, 'created_at'),
        denies=pulumi.get(__ret__, 'denies'),
        description=pulumi.get(__ret__, 'description'),
        excepts=pulumi.get(__ret__, 'excepts'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        owner=pulumi.get(__ret__, 'owner'),
        updated_at=pulumi.get(__ret__, 'updated_at'),
        urn=pulumi.get(__ret__, 'urn'))
def get_permissions_group_output(allows: Optional[pulumi.Input[Optional[Sequence[builtins.str]]]] = None,
                                 denies: Optional[pulumi.Input[Optional[Sequence[builtins.str]]]] = None,
                                 description: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                 excepts: Optional[pulumi.Input[Optional[Sequence[builtins.str]]]] = None,
                                 updated_at: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                 urn: Optional[pulumi.Input[builtins.str]] = None,
                                 opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetPermissionsGroupResult]:
    """
    Use this data source to access information about an existing resource.
    """
    __args__ = dict()
    __args__['allows'] = allows
    __args__['denies'] = denies
    __args__['description'] = description
    __args__['excepts'] = excepts
    __args__['updatedAt'] = updated_at
    __args__['urn'] = urn
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:Iam/getPermissionsGroup:getPermissionsGroup', __args__, opts=opts, typ=GetPermissionsGroupResult)
    return __ret__.apply(lambda __response__: GetPermissionsGroupResult(
        allows=pulumi.get(__response__, 'allows'),
        created_at=pulumi.get(__response__, 'created_at'),
        denies=pulumi.get(__response__, 'denies'),
        description=pulumi.get(__response__, 'description'),
        excepts=pulumi.get(__response__, 'excepts'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        owner=pulumi.get(__response__, 'owner'),
        updated_at=pulumi.get(__response__, 'updated_at'),
        urn=pulumi.get(__response__, 'urn')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ServerReinstallTaskArgs', 'ServerReinstallTask']

@pulumi.input_type
class ServerReinstallTaskArgs:
    def __init__(__self__, *,
                 os: pulumi.Input[builtins.str],
                 service_name: pulumi.Input[builtins.str],
                 bootid_on_destroy: Optional[pulumi.Input[builtins.int]] = None,
                 customizations: Optional[pulumi.Input['ServerReinstallTaskCustomizationsArgs']] = None,
                 properties: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 storages: Optional[pulumi.Input[Sequence[pulumi.Input['ServerReinstallTaskStorageArgs']]]] = None):
        """
        The set of arguments for constructing a ServerReinstallTask resource.
        :param pulumi.Input[builtins.str] os: Operating system to install.
        :param pulumi.Input[builtins.str] service_name: The service_name of your dedicated server.
        :param pulumi.Input[builtins.int] bootid_on_destroy: If set, reboot the server on the specified boot id during destroy phase.
        :param pulumi.Input['ServerReinstallTaskCustomizationsArgs'] customizations: Available attributes and their types are OS-dependant. Example: `hostname`.
               
               > **WARNING** Some customizations may be required on some Operating Systems. [Check how to list the available and required customization(s) for your operating system](https://help.ovhcloud.com/csm/en-dedicated-servers-api-os-installation?id=kb_article_view&sysparm_article=KB0061951#os-inputs) (do not forget to adapt camel case customization name to snake case parameter).
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] properties: Arbitrary properties to pass to cloud-init's config drive datasource. It supports any key with any string value.
        :param pulumi.Input[Sequence[pulumi.Input['ServerReinstallTaskStorageArgs']]] storages: OS reinstallation storage configurations. [More details about disks, hardware/software RAID and partitioning configuration](https://help.ovhcloud.com/csm/en-dedicated-servers-api-partitioning?id=kb_article_view&sysparm_article=KB0043882) (do not forget to adapt camel case parameters to snake case parameters).
        """
        pulumi.set(__self__, "os", os)
        pulumi.set(__self__, "service_name", service_name)
        if bootid_on_destroy is not None:
            pulumi.set(__self__, "bootid_on_destroy", bootid_on_destroy)
        if customizations is not None:
            pulumi.set(__self__, "customizations", customizations)
        if properties is not None:
            pulumi.set(__self__, "properties", properties)
        if storages is not None:
            pulumi.set(__self__, "storages", storages)

    @property
    @pulumi.getter
    def os(self) -> pulumi.Input[builtins.str]:
        """
        Operating system to install.
        """
        return pulumi.get(self, "os")

    @os.setter
    def os(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "os", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[builtins.str]:
        """
        The service_name of your dedicated server.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter(name="bootidOnDestroy")
    def bootid_on_destroy(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        If set, reboot the server on the specified boot id during destroy phase.
        """
        return pulumi.get(self, "bootid_on_destroy")

    @bootid_on_destroy.setter
    def bootid_on_destroy(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "bootid_on_destroy", value)

    @property
    @pulumi.getter
    def customizations(self) -> Optional[pulumi.Input['ServerReinstallTaskCustomizationsArgs']]:
        """
        Available attributes and their types are OS-dependant. Example: `hostname`.

        > **WARNING** Some customizations may be required on some Operating Systems. [Check how to list the available and required customization(s) for your operating system](https://help.ovhcloud.com/csm/en-dedicated-servers-api-os-installation?id=kb_article_view&sysparm_article=KB0061951#os-inputs) (do not forget to adapt camel case customization name to snake case parameter).
        """
        return pulumi.get(self, "customizations")

    @customizations.setter
    def customizations(self, value: Optional[pulumi.Input['ServerReinstallTaskCustomizationsArgs']]):
        pulumi.set(self, "customizations", value)

    @property
    @pulumi.getter
    def properties(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        Arbitrary properties to pass to cloud-init's config drive datasource. It supports any key with any string value.
        """
        return pulumi.get(self, "properties")

    @properties.setter
    def properties(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "properties", value)

    @property
    @pulumi.getter
    def storages(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ServerReinstallTaskStorageArgs']]]]:
        """
        OS reinstallation storage configurations. [More details about disks, hardware/software RAID and partitioning configuration](https://help.ovhcloud.com/csm/en-dedicated-servers-api-partitioning?id=kb_article_view&sysparm_article=KB0043882) (do not forget to adapt camel case parameters to snake case parameters).
        """
        return pulumi.get(self, "storages")

    @storages.setter
    def storages(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ServerReinstallTaskStorageArgs']]]]):
        pulumi.set(self, "storages", value)


@pulumi.input_type
class _ServerReinstallTaskState:
    def __init__(__self__, *,
                 bootid_on_destroy: Optional[pulumi.Input[builtins.int]] = None,
                 comment: Optional[pulumi.Input[builtins.str]] = None,
                 customizations: Optional[pulumi.Input['ServerReinstallTaskCustomizationsArgs']] = None,
                 done_date: Optional[pulumi.Input[builtins.str]] = None,
                 function: Optional[pulumi.Input[builtins.str]] = None,
                 last_update: Optional[pulumi.Input[builtins.str]] = None,
                 os: Optional[pulumi.Input[builtins.str]] = None,
                 properties: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 start_date: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 storages: Optional[pulumi.Input[Sequence[pulumi.Input['ServerReinstallTaskStorageArgs']]]] = None):
        """
        Input properties used for looking up and filtering ServerReinstallTask resources.
        :param pulumi.Input[builtins.int] bootid_on_destroy: If set, reboot the server on the specified boot id during destroy phase.
        :param pulumi.Input[builtins.str] comment: Details of this task. (should be `Install asked`)
        :param pulumi.Input['ServerReinstallTaskCustomizationsArgs'] customizations: Available attributes and their types are OS-dependant. Example: `hostname`.
               
               > **WARNING** Some customizations may be required on some Operating Systems. [Check how to list the available and required customization(s) for your operating system](https://help.ovhcloud.com/csm/en-dedicated-servers-api-os-installation?id=kb_article_view&sysparm_article=KB0061951#os-inputs) (do not forget to adapt camel case customization name to snake case parameter).
        :param pulumi.Input[builtins.str] done_date: Completion date in RFC3339 format.
        :param pulumi.Input[builtins.str] function: Function name (should be `hardInstall`).
        :param pulumi.Input[builtins.str] last_update: Last update
        :param pulumi.Input[builtins.str] os: Operating system to install.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] properties: Arbitrary properties to pass to cloud-init's config drive datasource. It supports any key with any string value.
        :param pulumi.Input[builtins.str] service_name: The service_name of your dedicated server.
        :param pulumi.Input[builtins.str] start_date: Task creation date in RFC3339 format.
        :param pulumi.Input[builtins.str] status: Task status (should be `done`)
        :param pulumi.Input[Sequence[pulumi.Input['ServerReinstallTaskStorageArgs']]] storages: OS reinstallation storage configurations. [More details about disks, hardware/software RAID and partitioning configuration](https://help.ovhcloud.com/csm/en-dedicated-servers-api-partitioning?id=kb_article_view&sysparm_article=KB0043882) (do not forget to adapt camel case parameters to snake case parameters).
        """
        if bootid_on_destroy is not None:
            pulumi.set(__self__, "bootid_on_destroy", bootid_on_destroy)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if customizations is not None:
            pulumi.set(__self__, "customizations", customizations)
        if done_date is not None:
            pulumi.set(__self__, "done_date", done_date)
        if function is not None:
            pulumi.set(__self__, "function", function)
        if last_update is not None:
            pulumi.set(__self__, "last_update", last_update)
        if os is not None:
            pulumi.set(__self__, "os", os)
        if properties is not None:
            pulumi.set(__self__, "properties", properties)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if start_date is not None:
            pulumi.set(__self__, "start_date", start_date)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if storages is not None:
            pulumi.set(__self__, "storages", storages)

    @property
    @pulumi.getter(name="bootidOnDestroy")
    def bootid_on_destroy(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        If set, reboot the server on the specified boot id during destroy phase.
        """
        return pulumi.get(self, "bootid_on_destroy")

    @bootid_on_destroy.setter
    def bootid_on_destroy(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "bootid_on_destroy", value)

    @property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Details of this task. (should be `Install asked`)
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "comment", value)

    @property
    @pulumi.getter
    def customizations(self) -> Optional[pulumi.Input['ServerReinstallTaskCustomizationsArgs']]:
        """
        Available attributes and their types are OS-dependant. Example: `hostname`.

        > **WARNING** Some customizations may be required on some Operating Systems. [Check how to list the available and required customization(s) for your operating system](https://help.ovhcloud.com/csm/en-dedicated-servers-api-os-installation?id=kb_article_view&sysparm_article=KB0061951#os-inputs) (do not forget to adapt camel case customization name to snake case parameter).
        """
        return pulumi.get(self, "customizations")

    @customizations.setter
    def customizations(self, value: Optional[pulumi.Input['ServerReinstallTaskCustomizationsArgs']]):
        pulumi.set(self, "customizations", value)

    @property
    @pulumi.getter(name="doneDate")
    def done_date(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Completion date in RFC3339 format.
        """
        return pulumi.get(self, "done_date")

    @done_date.setter
    def done_date(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "done_date", value)

    @property
    @pulumi.getter
    def function(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Function name (should be `hardInstall`).
        """
        return pulumi.get(self, "function")

    @function.setter
    def function(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "function", value)

    @property
    @pulumi.getter(name="lastUpdate")
    def last_update(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Last update
        """
        return pulumi.get(self, "last_update")

    @last_update.setter
    def last_update(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "last_update", value)

    @property
    @pulumi.getter
    def os(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Operating system to install.
        """
        return pulumi.get(self, "os")

    @os.setter
    def os(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "os", value)

    @property
    @pulumi.getter
    def properties(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        Arbitrary properties to pass to cloud-init's config drive datasource. It supports any key with any string value.
        """
        return pulumi.get(self, "properties")

    @properties.setter
    def properties(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "properties", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The service_name of your dedicated server.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter(name="startDate")
    def start_date(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Task creation date in RFC3339 format.
        """
        return pulumi.get(self, "start_date")

    @start_date.setter
    def start_date(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "start_date", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Task status (should be `done`)
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def storages(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ServerReinstallTaskStorageArgs']]]]:
        """
        OS reinstallation storage configurations. [More details about disks, hardware/software RAID and partitioning configuration](https://help.ovhcloud.com/csm/en-dedicated-servers-api-partitioning?id=kb_article_view&sysparm_article=KB0043882) (do not forget to adapt camel case parameters to snake case parameters).
        """
        return pulumi.get(self, "storages")

    @storages.setter
    def storages(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ServerReinstallTaskStorageArgs']]]]):
        pulumi.set(self, "storages", value)


class ServerReinstallTask(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bootid_on_destroy: Optional[pulumi.Input[builtins.int]] = None,
                 customizations: Optional[pulumi.Input[Union['ServerReinstallTaskCustomizationsArgs', 'ServerReinstallTaskCustomizationsArgsDict']]] = None,
                 os: Optional[pulumi.Input[builtins.str]] = None,
                 properties: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 storages: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ServerReinstallTaskStorageArgs', 'ServerReinstallTaskStorageArgsDict']]]]] = None,
                 __props__=None):
        """
        ## Import

        Installation task can be imported using the `service_name` (`nsXXXX.ip...`) of the baremetal server, the `operating_system` used and ths `task_id`, separated by "/" E.g.,

        bash

        ```sh
        $ pulumi import ovh:Dedicated/serverReinstallTask:ServerReinstallTask ovh_dedicated_server_reinstall_task nsXXXX.ipXXXX/operating_system/12345
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] bootid_on_destroy: If set, reboot the server on the specified boot id during destroy phase.
        :param pulumi.Input[Union['ServerReinstallTaskCustomizationsArgs', 'ServerReinstallTaskCustomizationsArgsDict']] customizations: Available attributes and their types are OS-dependant. Example: `hostname`.
               
               > **WARNING** Some customizations may be required on some Operating Systems. [Check how to list the available and required customization(s) for your operating system](https://help.ovhcloud.com/csm/en-dedicated-servers-api-os-installation?id=kb_article_view&sysparm_article=KB0061951#os-inputs) (do not forget to adapt camel case customization name to snake case parameter).
        :param pulumi.Input[builtins.str] os: Operating system to install.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] properties: Arbitrary properties to pass to cloud-init's config drive datasource. It supports any key with any string value.
        :param pulumi.Input[builtins.str] service_name: The service_name of your dedicated server.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ServerReinstallTaskStorageArgs', 'ServerReinstallTaskStorageArgsDict']]]] storages: OS reinstallation storage configurations. [More details about disks, hardware/software RAID and partitioning configuration](https://help.ovhcloud.com/csm/en-dedicated-servers-api-partitioning?id=kb_article_view&sysparm_article=KB0043882) (do not forget to adapt camel case parameters to snake case parameters).
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ServerReinstallTaskArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Import

        Installation task can be imported using the `service_name` (`nsXXXX.ip...`) of the baremetal server, the `operating_system` used and ths `task_id`, separated by "/" E.g.,

        bash

        ```sh
        $ pulumi import ovh:Dedicated/serverReinstallTask:ServerReinstallTask ovh_dedicated_server_reinstall_task nsXXXX.ipXXXX/operating_system/12345
        ```

        :param str resource_name: The name of the resource.
        :param ServerReinstallTaskArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ServerReinstallTaskArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bootid_on_destroy: Optional[pulumi.Input[builtins.int]] = None,
                 customizations: Optional[pulumi.Input[Union['ServerReinstallTaskCustomizationsArgs', 'ServerReinstallTaskCustomizationsArgsDict']]] = None,
                 os: Optional[pulumi.Input[builtins.str]] = None,
                 properties: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 storages: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ServerReinstallTaskStorageArgs', 'ServerReinstallTaskStorageArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ServerReinstallTaskArgs.__new__(ServerReinstallTaskArgs)

            __props__.__dict__["bootid_on_destroy"] = bootid_on_destroy
            __props__.__dict__["customizations"] = customizations
            if os is None and not opts.urn:
                raise TypeError("Missing required property 'os'")
            __props__.__dict__["os"] = os
            __props__.__dict__["properties"] = properties
            if service_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_name'")
            __props__.__dict__["service_name"] = service_name
            __props__.__dict__["storages"] = storages
            __props__.__dict__["comment"] = None
            __props__.__dict__["done_date"] = None
            __props__.__dict__["function"] = None
            __props__.__dict__["last_update"] = None
            __props__.__dict__["start_date"] = None
            __props__.__dict__["status"] = None
        super(ServerReinstallTask, __self__).__init__(
            'ovh:Dedicated/serverReinstallTask:ServerReinstallTask',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            bootid_on_destroy: Optional[pulumi.Input[builtins.int]] = None,
            comment: Optional[pulumi.Input[builtins.str]] = None,
            customizations: Optional[pulumi.Input[Union['ServerReinstallTaskCustomizationsArgs', 'ServerReinstallTaskCustomizationsArgsDict']]] = None,
            done_date: Optional[pulumi.Input[builtins.str]] = None,
            function: Optional[pulumi.Input[builtins.str]] = None,
            last_update: Optional[pulumi.Input[builtins.str]] = None,
            os: Optional[pulumi.Input[builtins.str]] = None,
            properties: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None,
            start_date: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            storages: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ServerReinstallTaskStorageArgs', 'ServerReinstallTaskStorageArgsDict']]]]] = None) -> 'ServerReinstallTask':
        """
        Get an existing ServerReinstallTask resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] bootid_on_destroy: If set, reboot the server on the specified boot id during destroy phase.
        :param pulumi.Input[builtins.str] comment: Details of this task. (should be `Install asked`)
        :param pulumi.Input[Union['ServerReinstallTaskCustomizationsArgs', 'ServerReinstallTaskCustomizationsArgsDict']] customizations: Available attributes and their types are OS-dependant. Example: `hostname`.
               
               > **WARNING** Some customizations may be required on some Operating Systems. [Check how to list the available and required customization(s) for your operating system](https://help.ovhcloud.com/csm/en-dedicated-servers-api-os-installation?id=kb_article_view&sysparm_article=KB0061951#os-inputs) (do not forget to adapt camel case customization name to snake case parameter).
        :param pulumi.Input[builtins.str] done_date: Completion date in RFC3339 format.
        :param pulumi.Input[builtins.str] function: Function name (should be `hardInstall`).
        :param pulumi.Input[builtins.str] last_update: Last update
        :param pulumi.Input[builtins.str] os: Operating system to install.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] properties: Arbitrary properties to pass to cloud-init's config drive datasource. It supports any key with any string value.
        :param pulumi.Input[builtins.str] service_name: The service_name of your dedicated server.
        :param pulumi.Input[builtins.str] start_date: Task creation date in RFC3339 format.
        :param pulumi.Input[builtins.str] status: Task status (should be `done`)
        :param pulumi.Input[Sequence[pulumi.Input[Union['ServerReinstallTaskStorageArgs', 'ServerReinstallTaskStorageArgsDict']]]] storages: OS reinstallation storage configurations. [More details about disks, hardware/software RAID and partitioning configuration](https://help.ovhcloud.com/csm/en-dedicated-servers-api-partitioning?id=kb_article_view&sysparm_article=KB0043882) (do not forget to adapt camel case parameters to snake case parameters).
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ServerReinstallTaskState.__new__(_ServerReinstallTaskState)

        __props__.__dict__["bootid_on_destroy"] = bootid_on_destroy
        __props__.__dict__["comment"] = comment
        __props__.__dict__["customizations"] = customizations
        __props__.__dict__["done_date"] = done_date
        __props__.__dict__["function"] = function
        __props__.__dict__["last_update"] = last_update
        __props__.__dict__["os"] = os
        __props__.__dict__["properties"] = properties
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["start_date"] = start_date
        __props__.__dict__["status"] = status
        __props__.__dict__["storages"] = storages
        return ServerReinstallTask(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="bootidOnDestroy")
    def bootid_on_destroy(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        If set, reboot the server on the specified boot id during destroy phase.
        """
        return pulumi.get(self, "bootid_on_destroy")

    @property
    @pulumi.getter
    def comment(self) -> pulumi.Output[builtins.str]:
        """
        Details of this task. (should be `Install asked`)
        """
        return pulumi.get(self, "comment")

    @property
    @pulumi.getter
    def customizations(self) -> pulumi.Output[Optional['outputs.ServerReinstallTaskCustomizations']]:
        """
        Available attributes and their types are OS-dependant. Example: `hostname`.

        > **WARNING** Some customizations may be required on some Operating Systems. [Check how to list the available and required customization(s) for your operating system](https://help.ovhcloud.com/csm/en-dedicated-servers-api-os-installation?id=kb_article_view&sysparm_article=KB0061951#os-inputs) (do not forget to adapt camel case customization name to snake case parameter).
        """
        return pulumi.get(self, "customizations")

    @property
    @pulumi.getter(name="doneDate")
    def done_date(self) -> pulumi.Output[builtins.str]:
        """
        Completion date in RFC3339 format.
        """
        return pulumi.get(self, "done_date")

    @property
    @pulumi.getter
    def function(self) -> pulumi.Output[builtins.str]:
        """
        Function name (should be `hardInstall`).
        """
        return pulumi.get(self, "function")

    @property
    @pulumi.getter(name="lastUpdate")
    def last_update(self) -> pulumi.Output[builtins.str]:
        """
        Last update
        """
        return pulumi.get(self, "last_update")

    @property
    @pulumi.getter
    def os(self) -> pulumi.Output[builtins.str]:
        """
        Operating system to install.
        """
        return pulumi.get(self, "os")

    @property
    @pulumi.getter
    def properties(self) -> pulumi.Output[Optional[Mapping[str, builtins.str]]]:
        """
        Arbitrary properties to pass to cloud-init's config drive datasource. It supports any key with any string value.
        """
        return pulumi.get(self, "properties")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        The service_name of your dedicated server.
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter(name="startDate")
    def start_date(self) -> pulumi.Output[builtins.str]:
        """
        Task creation date in RFC3339 format.
        """
        return pulumi.get(self, "start_date")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        Task status (should be `done`)
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def storages(self) -> pulumi.Output[Optional[Sequence['outputs.ServerReinstallTaskStorage']]]:
        """
        OS reinstallation storage configurations. [More details about disks, hardware/software RAID and partitioning configuration](https://help.ovhcloud.com/csm/en-dedicated-servers-api-partitioning?id=kb_article_view&sysparm_article=KB0043882) (do not forget to adapt camel case parameters to snake case parameters).
        """
        return pulumi.get(self, "storages")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetReferenceActionsActionResult',
]

@pulumi.output_type
class GetReferenceActionsActionResult(dict):
    def __init__(__self__, *,
                 action: builtins.str,
                 categories: Sequence[builtins.str],
                 description: builtins.str,
                 resource_type: builtins.str):
        """
        :param builtins.str action: Name of the action
        :param Sequence[builtins.str] categories: List of the categories of the action
        :param builtins.str description: Description of the action
        :param builtins.str resource_type: Resource type the action is related to
        """
        pulumi.set(__self__, "action", action)
        pulumi.set(__self__, "categories", categories)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "resource_type", resource_type)

    @property
    @pulumi.getter
    def action(self) -> builtins.str:
        """
        Name of the action
        """
        return pulumi.get(self, "action")

    @property
    @pulumi.getter
    def categories(self) -> Sequence[builtins.str]:
        """
        List of the categories of the action
        """
        return pulumi.get(self, "categories")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        Description of the action
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="resourceType")
    def resource_type(self) -> builtins.str:
        """
        Resource type the action is related to
        """
        return pulumi.get(self, "resource_type")


